@@ -97,7 +97,8 @@
 #' @return Invisibly return the `sim_type` `character` string. The function is
 #' called for its side-effects, which will error if the input is invalid.
 #' @keywords internal
-.check_sim_input <- function(sim_type = c("linelist", "contacts", "outbreak"), # nolint cyclocomp_linter
+# nolint start: cyclocomp_linter.
+.check_sim_input <- function(sim_type = c("linelist", "contacts", "outbreak"),
                              contact_distribution,
                              infectious_period,
                              prob_infection,
@@ -106,6 +107,7 @@
                              onset_to_hosp = NULL,
                              onset_to_death = NULL,
                              onset_to_recovery = NULL,
+                             reporting_delay = NULL,
                              anonymise = NULL,
                              case_type_probs = NULL,
                              contact_tracing_status_probs = NULL,
@@ -131,6 +133,18 @@
     .check_func_req_args(onset_to_hosp, func_name = "onset_to_hosp")
     .check_func_req_args(onset_to_death, func_name = "onset_to_death")
     .check_func_req_args(onset_to_recovery, func_name = "onset_to_recovery")
+    .check_func_req_args(reporting_delay, func_name = "reporting_delay")
+
+    # check if reporting_delay generates a number
+    reporting_delay_eval <- reporting_delay(1)
+    if (!is.numeric(reporting_delay_eval)) {
+      stop(
+        "The `reporting_delay` must be NULL or a function that ",
+        "generates numbers.",
+        call. = FALSE
+      )
+    }
+
     checkmate::assert_logical(anonymise, len = 1)
     checkmate::assert_numeric(case_type_probs, len = 3, lower = 0, upper = 1)
     checkmate::assert_names(
@@ -180,6 +194,7 @@
 
   invisible(sim_type)
 }
+# nolint end
 
 #' Check distribution function has n required arguments
 #'
@@ -200,7 +215,7 @@
   # for which formals(fn) would return NULL and cause the check to error
   # errors non-informatively for specials such as `if`
   valid_func <- checkmate::test_function(func) &&
-    sum(mapply(function(x, y) { # nolint undesirable function
+    sum(mapply(function(x, y) { # nolint: undesirable_function.
       is.name(x) && y != "..."
     }, formals(args(func)), names(formals(args(func))))) == n_req_args
 
@@ -251,7 +266,7 @@
 #' called for its side-effects, which will error or warn if the input is
 #' invalid.
 #' @keywords internal
-.cross_check_sim_input <- function(onset_to_hosp, # nolint cyclocomp_linter
+.cross_check_sim_input <- function(onset_to_hosp, # nolint: cyclocomp_linter.
                                    onset_to_death,
                                    hosp_risk,
                                    hosp_death_risk,
