@@ -125,8 +125,11 @@
 #' onset-to-recovery times in the line list may not resemble the distributional
 #' form input into the function.
 #'
-#' @param reporting_delay A `function` for the reporting delay distribution or
-#' `NULL`. The (random) number generating function creates delays between the
+#' @param reporting_delay A `function` or an `<epiparameter>` object for the
+#' reporting delay distribution. `reporting_delay` can also be `NULL` to not
+#' simulate delays from symptom onset to date of reporting, in which case the
+#' date of reporting will be assumed to be equal to the date of onset.
+#' The (random) number generating function creates delays between the
 #' time of symptom onset (`$date_onset`) and the case being reported
 #' (`$date_reporting`).
 #'
@@ -293,11 +296,11 @@
 #'   hosp_risk = age_dep_hosp_risk
 #' )
 #' head(linelist)
-sim_linelist <- function(contact_distribution = function(x) stats::dpois(x = x, lambda = 2), # nolint start line_lenght_linter
-                         infectious_period = function(x) stats::rlnorm(n = x, meanlog = 2, sdlog = 0.5),
+sim_linelist <- function(contact_distribution = function(x) stats::dpois(x = x, lambda = 2), # nolint start: line_length_linter.
+                         infectious_period = function(n) stats::rlnorm(n = n, meanlog = 2, sdlog = 0.5),
                          prob_infection = 0.5,
-                         onset_to_hosp = function(x) stats::rlnorm(n = x, meanlog = 1.5, sdlog = 0.5),
-                         onset_to_death = function(x) stats::rlnorm(n = x, meanlog = 2.5, sdlog = 0.5), # nolint end line_lenght_linter
+                         onset_to_hosp = function(n) stats::rlnorm(n = n, meanlog = 1.5, sdlog = 0.5),
+                         onset_to_death = function(n) stats::rlnorm(n = n, meanlog = 2.5, sdlog = 0.5), # nolint end
                          onset_to_recovery = NULL,
                          reporting_delay = NULL,
                          hosp_risk = 0.2,
@@ -341,7 +344,8 @@ sim_linelist <- function(contact_distribution = function(x) stats::dpois(x = x,
       infectious_period = infectious_period,
       onset_to_hosp = onset_to_hosp,
       onset_to_death = onset_to_death,
-      onset_to_recovery = onset_to_recovery
+      onset_to_recovery = onset_to_recovery,
+      reporting_delay = reporting_delay
     )
   )
   contact_distribution <- funcs$contact_distribution
@@ -349,6 +353,7 @@ sim_linelist <- function(contact_distribution = function(x) stats::dpois(x = x,
   onset_to_hosp <- funcs$onset_to_hosp
   onset_to_death <- funcs$onset_to_death
   onset_to_recovery <- funcs$onset_to_recovery
+  reporting_delay <- funcs$reporting_delay
 
   .check_sim_input(
     sim_type = "linelist",
@@ -360,6 +365,7 @@ sim_linelist <- function(contact_distribution = function(x) stats::dpois(x = x,
     onset_to_hosp = onset_to_hosp,
     onset_to_death = onset_to_death,
     onset_to_recovery = onset_to_recovery,
+    reporting_delay = reporting_delay,
     anonymise = anonymise,
     case_type_probs = case_type_probs,
     hosp_risk = hosp_risk,
