@@ -162,14 +162,15 @@ test_that(".check_df fails as expected for age", {
 })
 
 contact_distribution <- function(x) stats::dpois(x = x, lambda = 2)
-infectious_period <- function(x) stats::rgamma(n = x, shape = 1, scale = 1)
-onset_to_hosp <- function(x) {
-  stats::rlnorm(n = x, meanlog = 0.947, sdlog = 1.628)
+infectious_period <- function(n) stats::rgamma(n = n, shape = 1, scale = 1)
+onset_to_hosp <- function(n) {
+  stats::rlnorm(n = n, meanlog = 0.947, sdlog = 1.628)
 }
-onset_to_death <- function(x) {
-  stats::rlnorm(n = x, meanlog = 2.863, sdlog = 0.534)
+onset_to_death <- function(n) {
+  stats::rlnorm(n = n, meanlog = 2.863, sdlog = 0.534)
 }
-onset_to_recovery <- function(x) stats::rlnorm(n = x, meanlog = 3, sdlog = 1)
+onset_to_recovery <- function(n) stats::rlnorm(n = n, meanlog = 3, sdlog = 1)
+reporting_delay <- function(n) rep(0, times = n)
 
 test_that(".check_sim_input works as expected", {
   chk <- .check_sim_input(
@@ -182,6 +183,7 @@ test_that(".check_sim_input works as expected", {
     onset_to_hosp = onset_to_hosp,
     onset_to_death = onset_to_death,
     onset_to_recovery = onset_to_recovery,
+    reporting_delay = reporting_delay,
     anonymise = FALSE,
     case_type_probs = c(
       suspected = 0.2,
@@ -211,6 +213,7 @@ test_that(".check_sim_input works as expected", {
     onset_to_hosp = onset_to_hosp,
     onset_to_death = onset_to_death,
     onset_to_recovery = onset_to_recovery,
+    reporting_delay = reporting_delay,
     anonymise = FALSE,
     case_type_probs = c(
       suspected = 0.2,
@@ -254,6 +257,7 @@ test_that(".check_sim_input works as expected with NULL risks", {
     onset_to_hosp = onset_to_hosp,
     onset_to_death = onset_to_death,
     onset_to_recovery = onset_to_recovery,
+    reporting_delay = reporting_delay,
     anonymise = FALSE,
     case_type_probs = c(
       suspected = 0.2,
@@ -317,6 +321,23 @@ test_that(".check_sim_input fails as expected", {
     ),
     regexp = "(Assertion on)*(outbreak_size)*(failed)"
   )
+  expect_error(
+    .check_sim_input(
+      sim_type = "linelist",
+      contact_distribution = contact_distribution,
+      infectious_period = infectious_period,
+      prob_infection = 0.5,
+      outbreak_start_date = as.Date("2023-01-01"),
+      outbreak_size = c(10, 1e4),
+      population_age = c(1, 90),
+      onset_to_hosp = function(n) rlnorm(n = n, meanlog = 1, sdlog = 1),
+      onset_to_death = function(n) rlnorm(n = n, meanlog = 1, sdlog = 1),
+      onset_to_recovery = function(n) rlnorm(n = n, meanlog = 1, sdlog = 1),
+      reporting_delay = function(n) rep("0", times = n)
+    ),
+    regexp =
+      "The `reporting_delay` must be NULL or a function that generates numbers."
+  )
 })
 
 test_that(".cross_check_sim_input works as expected with numeric risk", {
@@ -359,7 +380,7 @@ test_that(".cross_check_sim_input works as expected with <data.frame> risks", {
 test_that(".cross_check_sim_input warns as expected", {
   expect_warning(
     .cross_check_sim_input(
-      onset_to_hosp = function(x) rep(NA, times = x),
+      onset_to_hosp = function(n) rep(NA, times = n),
       onset_to_death = onset_to_death,
       hosp_risk = 0.2,
       hosp_death_risk = 0.5,
@@ -373,7 +394,7 @@ test_that(".cross_check_sim_input warns as expected", {
 
   expect_warning(
     .cross_check_sim_input(
-      onset_to_hosp = function(x) rep(NA, times = x),
+      onset_to_hosp = function(n) rep(NA, times = n),
       onset_to_death = onset_to_death,
       hosp_risk = 0.2,
       hosp_death_risk = 0.5,
@@ -387,7 +408,7 @@ test_that(".cross_check_sim_input warns as expected", {
   expect_warning(
     .cross_check_sim_input(
       onset_to_hosp = onset_to_hosp,
-      onset_to_death = function(x) rep(NA, times = x),
+      onset_to_death = function(n) rep(NA, times = n),
       hosp_risk = 0.2,
       hosp_death_risk = 0.5,
       non_hosp_death_risk = 0.05
