@@ -4,7 +4,7 @@ test_that("sim_contacts works as expected with defaults", {
 })
 
 contact_distribution <- function(x) stats::dpois(x = x, lambda = 2)
-infectious_period <- function(x) stats::rgamma(n = x, shape = 1, scale = 1)
+infectious_period <- function(n) stats::rgamma(n = n, shape = 1, scale = 1)
 
 test_that("sim_contacts works as expected", {
   set.seed(1)
@@ -25,7 +25,7 @@ test_that("sim_contacts works as expected with modified config", {
       infectious_period = infectious_period,
       prob_infection = 0.5,
       config = create_config(
-        last_contact_distribution = function(x) stats::rgeom(n = x, prob = 0.5)
+        last_contact_distribution = function(n) stats::rgeom(n = n, prob = 0.5)
       )
     )
   )
@@ -39,7 +39,7 @@ test_that("sim_contacts works as expected with modified config parameters", {
       infectious_period = infectious_period,
       prob_infection = 0.5,
       config = create_config(
-        last_contact_distribution = function(x) stats::rpois(n = x, lambda = 5)
+        last_contact_distribution = function(n) stats::rpois(n = n, lambda = 5)
       )
     )
   )
@@ -52,7 +52,7 @@ test_that("sim_contacts fails as expected with modified config", {
       infectious_period = infectious_period,
       prob_infection = 0.5,
       config = create_config(
-        last_contact_distribution = function(x) stats::rgeom(n = x, lambda = 1)
+        last_contact_distribution = function(n) stats::rgeom(n = n, lambda = 1)
       )
     ),
     regexp = "(used argument)*(lambda = 1)"
